 function [M,t]=MakeTrig(x)
% MakeTrig - Create the orthonormal trig matrix M needed for slow DFT
%
% Syntax:  [M,t]=MakeTrig(x)
%
% Input: 
%	if x is a scalar, x = D = the number of sample points.
%	if x is a vector, x = equally-spaced sample times over interval [0,L]
%       and D = length(x) = number of sample points.
%   By convention, the samples occur at the beginning of each interval
%   
% Output: 
%	M = DxD matrix, each row is a sampled harmonic sine or cosine wave.
%	t = vector of sample angles over interval [0,2pi] used to make M
%
% Comments:
%	This matrix has row vectors which are the sampled cosine and sine 
%	  functions for various harmonics of the observation interval. 
%	See eqn. [3.39] in class notes for V791. 
%	Note that first coefficient = a0/sqrt(2) and last coefficient
%	  when D = even is a/sqrt(2).
%
% LNT 10Feb03 for V791 class; simplified 26Jan06; edit comments 27Sep2012 

% determine the type of input and define appropriate vector of sample times
if length(x) == 1				% user requests D samples over [0:2pi]
	t = [0:(x-1)]*2*pi./x;      % vector of sample angles (radians)
    D = length(t);              % number of sample points
else
	D = length(x);				% the number of data points
	L = D*(x(2)-x(1));			% length of interval
	t = 2*pi*x/L;				% the sample angles, theta
end
s = sqrt(D/2);                  % a scaling constant to normalize M
ss = sqrt(D);                   % special scaling constant

if mod(D,2) == 1				% branch for D odd
	maxharm = (D-1)/2;			% maximum harmonic number for this D value
	row = 1;					% row 1 is a special case
	M(row,:) =cos(0*t)/ss;      % scale row 1 to make it unit length
	
	for harm = 1:maxharm,		% fill in the other rows
		row = row+1;
		M(row,:)  = cos(harm*t)/s; % vector of sampled cosines
		row = row +1;
		M(row,:) = sin(harm*t)/s;  % vector of sampled sines
	end;
	
elseif mod(D,2) == 0            % branch for D even
	maxharm = (D)/2;			% maximum harmonic number for this D value
	row = 1;					
	M(row,:) =cos(0*t)/ss;      % first row is a special case
	
	for harm = 1:maxharm-1,		% fill in the other rows
		row = row+1;
		M(row,:)  = cos(harm*t)/s;  % vector of sampled cosines
		row = row+1;
		M(row,:) = sin(harm*t)/s;   % vector of sampled sines
	end;
	row = row+1;				
	M(row,:) =cos(maxharm*t)/ss;    % last row is a special case
	
else
	error ('D must be an integer')	
end
