function [T2,xbar,df1,df2,F_data,P]=T2OneMean(x,m,alpha)
% T2OneMean-  Test if multivariate mean equals given vector
%
% Based on Anderson's description of use of Hotelling's T-squared statistic
%  to test the null hypothesis that empirical mean vector = a given vector.
% See one-sample problem, p. 164 of
% "An Introduction to Multivariate Statistics", T.W. Anderson, 1984
%
% Usage:  [T2,xbar,df1,df2,F_data,p] = T2OneMean(x,m,alpha)
%
% Input arguments:
%	x = data matrix, with each row an observation and each column a variable.
%	m = given vector, default = 0
%	alpha = level of the F-test = prob(false rejection of null hypothesis),
%       default = 0.05
%
% Output argument:
%	T2 = Hotelling's T^2 statistic
%	xbar = mean vector computed from input matrix
%	df1 = lesser degrees of freedom
%	df2 = greater degrees of freedom
%	F_data = computed Fisher F-statistic
%	P value for F_data
%
% LNT 21-Nov-99. 
% LNT 6-Apr-02.  Add p to the list of output arguments.  Add legality check
%   on size of x. 
% LNT 26-Mar-06. Change default alpha to 0.05 to match corr2d.m

if nargin < 3
	alpha = 0.05	% default level of the test
end

[N,p] = size(x);

if nargin < 2
	m = zeros(p,1);	% default is to test if mean = 0
end

% legality check on given vector m
[row,col] = size(m);
if col ~=1
	m = m';			% must be a column vector
	[row,col] = size(m);
	if col ~=1
		error ('Second argument must be a vector')
	end
end

% legality check on dimensionality of x (Anderson, p. 157)
if N <= p
	error('Number of observations must exceed the length of each observation vector')
end

xbar = mean(x)';			% compute mean vector from data

% Next compute covariance matrix 
S = cov(x);					% covariance matrix for X
A = (N-1) * S;				% sum of squares for X
AI = inv(A);				% inverse of A

% Do the test (eqns. 2,3,5 of Anderson, p. 164)

T2 = N*(N-1) * (xbar - m)' * AI * (xbar - m); % a scalar
df1 = p;				% denominator degrees of freedom
df2 = N-p;				% numerator degrees of freedom
F_data = (df2/df1)*T2/(N-1);

prob = 1 - alpha;
F_table = finv(prob,df1,df2);

if F_data > F_table
	msg = 'Hypothesis that population mean = given vector MAY be rejected'
else
	msg = 'Hypothesis that population mean = given vector MAY NOT be rejected'
end

P = 1 - fcdf(F_data,df1,df2);
