function [T2,xbar,ybar,df1,df2,F_data,P]=T2TwoMeans(x,y,alpha)
% T2_compare_means  Compare two multivariate means with T-squared statistic
%
% Based on Anderson's example of use of Hotelling's T-squared statistic to
%  test the null hypothesis that two empirical mean vectors are equal.
% See two-sample problem, p. 167 of
% "An Introduction to Multivariate Statistics", T.W. Anderson, 1984
%
% Usage:  [T2,xbar,ybar,df1,df2,F_data,p]=T2TwoMeans(x,y,alpha)
%
% Input arguments:
%	x = data matrix #1, with each row an observation and each column a variable.
%	y = data matrix #2, with each row an observation and each column a variable.
%	alpha = level of the F-test = prob(false rejection of null hypothesis) 
%
% Output argument:
%	T2 = Hotelling's T2 statistic
%	xbar = mean vector computed from input matrix x
%	ybar = mean vector computed from input matrix y
%	df1 = lesser degrees of freedom
%	df2 = greater degrees of freedom
%	F_data = computed Fisher F-statistic
%	p value for F_data
%
% LNT 21-Nov-99. This routine was verified using Fisher's iris data.  Results
%  are close to those published in Anderson's book.  Assume differences are
%  due to numerical rounding errors.
% LNT 6-Apr-02.  Add p to the list of output arguments.  Add legality checks.

if size(x)~=size(y)
	error('Input matrices must be the same size')
end

if nargin < 3
	alpha = 0.05	% default level of the test
end

% First get the sample size and mean vector for each population
[N1,p] = size(x);
[N2,q] = size(y);

% Legality checks
if p ~= q, error('Number of colums of input matrices must be equal'), end
if (N1+N2-p-1) <= 0, error('Insufficient number of observations for this test'), end

xbar = mean(x)';			% compute mean vectors
ybar = mean(y)';

% Next compute covariance matrix for combined population 
%  Method is described by eqn. 16 on pl 167 of Anderson
SX = cov(x);				% covariance matrix for X
SofS_X = (N1-1) * SX;			% sum of squares for X
SY = cov(y);				% covariance matrix for Y
SofS_Y = (N2-1) * SY;			% sum of squares for Y
SofS_XY = SofS_X + SofS_Y;	% combines sum of squares
S = SofS_XY/(N1+N2-2);		% covariance matrix for combined data 
SI = inv(S);				% inverse of S

% Do the test
T2 = N1*N2/(N1+N2) * (xbar - ybar)' * SI * (xbar - ybar);
df1 = p;
df2 = N1+N2-p-1;				% greater degrees of freedom
F_data = (df2/df1)*T2/(N1+N2-2);

prob = 1 - alpha;
F_table = finv(prob,df1,df2);

if F_data > F_table
	msg = 'Hypothesis that two population means are equal MAY be rejected'
else
	msg = 'Hypothesis that two population means are equal may NOT be rejected'
end

P = 1 - fcdf(F_data,df1,df2);
