function yi = interpsinc(x,y,xi)  
%INTERPSINC Interpolate a sampled function y(x) using sinc(x)=sin(pi*x)/pi*x 
%
% Syntax: yi = interpsinc2(x,y,xi); % call without arguments to see a demonstration
%
% Input arguments
%   x = vector of equally-spaced sample locations for y
%   y = vector of sample values at locations x
%   xi = the x locations for which the function y(x) is to be interpolated
%
% Unused arguments:
%   xd is the sample spacing of the elements of f
%      optional, assumed to be 1 if not present
%   nref is the reference element of vector f, 
%      optional, assumed to be zero if ommitted
%      (the first element of f is labeled element 1)
%   nrefx is the x value assigned to element nref
%      optional, assumed to be 0 if omitted
%
%   If all three arguments are omitted the vector f is assumed to be f(x) evaluated
%   at x=1,2,3 ... length(f)
%
%REF: Discrete-Time Signal Processing, Oppenheim and Schafer, 1989, Pages: 89-91
%Author: Michael Minardi Ph.D., email: minardi2@mbvlab.wpafb.af.mil, October 1999
% LNT 26Nov2012 - rework the input arguments to mimic interp1.m

% EXAMPLE, interpolate values for a sine wave sampled at twice Nyquist frequency
% Since sinc interpolation represents ideal low-pass filtering, we expect
%   the interpolated values to match the sine values almost exactly.
if nargin<1, 
  x=0:pi/4:20*pi;
  y=sin(x); % "f" is a vector of samples of a sine wave sampled every pi/4 radians (90 degrees)
  xi=[71/8*pi:pi/4:89/8*pi];
  yi=interpsinc(x,y,xi) % estimate sine wave at some points halfway between samples
  figure; plot(xi,yi,'ko',xi,sin(xi),'b-') % compare to true value of sine waves at these points
  legend('Interpolated','True values')
end

% Use cell array varargin to set optional input values xd, nref and nrefx
% d={1,0,0};d(1:length(varargin))=varargin;
xd = x(2)-x(1); %xd=d{1};
nref = 1; % nref=d{2};
nrefx = x(1);  %nrefx=d{3};
%convert xi from units of x to fractional index values
ni=nref+(xi-nrefx)/xd;
% convert ni to a row vector
ni=ni(:)';
% convert f to a row vector
if prod(size(y))>max(size(y));
   warning('input function "f" is not a vector, will vectorize by columns')
end
y=y(:)';
% Check to see if some requested interpolation points are outside the range of the sampled function
if min(ni)<1|max(ni)>length(y)
   warning('some points are outside the range of the input function,') 
   warning('you are EXTRAPOLATING not INTERPOLATING, results are likely to stink!')
end
% create interpolation weights using the sinc function
A = [1:length(y)]'*ones(size(ni)); % replicates a column of integer sequence 1:n, every col is the same
B = ones(size(y'))*ni; % replicate the sample vector ni, every row is the same
NI=sinc(A-B); % each row of NI is a shifted version of ni
% create interpolated values as series of inner products, each with shifted version of the sinc function
yi=y*NI;  % [1 x n] row vector * [n x i] matrix = [1 x i] vector of inner products
% convert answer (yi) back to original shape of input xi
yi=reshape(yi,size(xi));


